shared

package
v2.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	ErrorPrefix = "[sypl] [Error]"
	WarnPrefix  = "[sypl] [Warn]"
)

Standard logging prefix for internal errors.

const (
	FilterEnvVar = "SYPL_FILTER"
	LevelEnvVar  = "SYPL_LEVEL"
)

Env vars that affects Sypl.

const (
	DefaultFileMode = 0o644
)

Default values.

Variables

This section is empty.

Functions

func GenerateUUID

func GenerateUUID() string

GenerateUUID generates a RFC4122 UUID and DCE 1.1: Authentication and Security Services.

func Inline

func Inline(data interface{}) string

Inline encodes JSON in line.

NOTE: Only exported fields of the data structure will be printed.

func Prettify

func Prettify(data interface{}) string

Prettify encodes data returning its JSON-stringified version.

NOTE: Only exported fields of the data structure will be printed.

Types

This section is empty.

Jump to